diff -Nur openbsc.old/src/gsm_04_08.c openbsc.new/src/gsm_04_08.c
--- openbsc.old/src/gsm_04_08.c	2009-06-06 09:30:25.000000000 +0200
+++ openbsc.new/src/gsm_04_08.c	2009-06-06 10:02:47.000000000 +0200
@@ -938,6 +939,7 @@
 	u_int8_t mi_type = mi_lv[1] & GSM_MI_TYPE_MASK;
 	char mi_string[MI_SIZE];
 	struct gsm_subscriber *subscr;
+	struct gsm_bts *bts;
 	struct paging_signal_data sig_data;
 	int rc = 0;
 
@@ -977,8 +979,22 @@
 	sig_data.lchan	= msg->lchan;
 
 	dispatch_signal(SS_PAGING, S_PAGING_COMPLETED, &sig_data);
+
+	/* Stop paging on the bts we received the paging response */
 	paging_request_stop(msg->trx->bts, subscr, msg->lchan);
 
+	/* Stop paging on all other bts' */
+	bts = NULL;
+	do {
+		bts = gsm_bts_by_lac(msg->trx->bts->network, subscr->lac, bts);
+		if (!bts)
+			break;
+		if (bts == msg->trx->bts)
+			continue;
+		/* Stop paging */
+		paging_request_stop(bts, subscr, NULL);
+	} while (1);
+
 	/* FIXME: somehow signal the completion of the PAGING to
 	 * the entity that requested the paging */
 
@@ -1137,6 +1153,7 @@
 	struct gsm48_hdr *gh = msgb_l3(msg);
 	unsigned int payload_len = msgb_l3len(msg) - sizeof(*gh);
 	struct gsm_subscriber *called_subscr;
+	struct gsm_bts *bts;
 	char called_number[(43-2)*2 + 1] = "\0";
 	struct tlv_parsed tp;
 	u_int8_t num_type;
@@ -1180,12 +1197,16 @@
 	subscr_get(msg->lchan->subscr);
 	call->called_subscr = called_subscr;
 
-	/* start paging of the receiving end of the call */
-	/* FIXME: we're assuming that the receiver is at the same BTS
-	 * than we are, which is obviously a wrong assumption in multi-BTS
-	 * case */
-	paging_request(msg->trx->bts, called_subscr, RSL_CHANNEED_TCH_F,
-			setup_trig_pag_evt, call);
+	/* Start paging subscriber on all BTS with her location */
+	bts = NULL;
+	do {
+		bts = gsm_bts_by_lac(msg->trx->bts->network, msg->lchan->subscr->lac, bts);
+		if (!bts)
+			break;
+		/* Trigger paging */
+		paging_request(bts, called_subscr, RSL_CHANNEED_TCH_F,
+				setup_trig_pag_evt, call);
+	} while (1);
 
 	/* send a CALL PROCEEDING message to the MO */
 	ret = gsm48_tx_simple(msg->lchan, GSM48_PDISC_CC,
diff -Nur openbsc.old/src/paging.c openbsc.new/src/paging.c
--- openbsc.old/src/paging.c	2009-05-23 17:32:17.000000000 +0200
+++ openbsc.new/src/paging.c	2009-06-06 10:58:30.000000000 +0200
@@ -247,7 +247,7 @@
 	llist_for_each_entry_safe(req, req2, &bts_entry->pending_requests,
 				 entry) {
 		if (req->subscr == subscr) {
-			if (req->cbfn)
+			if (lchan && req->cbfn)
 				req->cbfn(GSM_HOOK_RR_PAGING, GSM_PAGING_SUCCEEDED,
 					  NULL, lchan, req->cbfn_param);
 			paging_remove_request(&bts->paging, req);
